@@ -475,12 +475,16 @@ EXTERN_FUNCTION(void Mrandom, (Minteger * a));
 
 /*		random.h		*/
 
-#ifndef ___SGI
+#ifndef SRANDOM_IN_MATH_H
 void 	srandom();	/* void srandom(unsigned); */
 #endif
+#ifndef INITSTATE_IN_MATH_H
 char * 	initstate();	/* char* initstate(unsigned, char *, int); */
+#endif
+#ifndef SETSTATE_IN_MATH_H
 char *	setstate();	/* char* setstate(char *); */
-#ifndef ___SGI
+#endif
+#ifndef RANDOM_IN_MATH_H
 long	random();	/* returns random 31 lower bits */
 #endif        
 
